@@ -29,6 +29,8 @@ sub get {
 			'item edit-delete',
 			'',
 			'item find-selection',
+			'item replace-selection',
+			'item tool-note-selection',
 			'',
 			'item edit-selection-convert-uppercase',
 			'item edit-selection-convert-lowercase',
@@ -47,40 +49,53 @@ sub get {
 			'radioitem search-range-open-docs',
 		],
 		'document_syntaxstyle_contextmenu' => [
-			'checkitem document-syntaxmode-c',
-			'checkitem document-syntaxmode-conf',
-			'checkitem document-syntaxmode-css',
-			'checkitem document-syntaxmode-html',
-			'checkitem document-syntaxmode-js',
-			'checkitem document-syntaxmode-perl',
-			'checkitem document-syntaxmode-xml',
-			'checkitem document-syntaxmode-yaml',
+			'radioitem document-syntaxmode-c',
+			'radioitem document-syntaxmode-conf',
+			'radioitem document-syntaxmode-css',
+			'radioitem document-syntaxmode-html',
+			'radioitem document-syntaxmode-js',
+			'radioitem document-syntaxmode-perl',
+			'radioitem document-syntaxmode-xml',
+			'radioitem document-syntaxmode-yaml',
 			'',
 			'item document-syntaxmode-auto',
 			'checkitem document-syntaxmode-none',
 		],
 		'document_whitespace_contextmenu' => [
-			'item edit-document-format-del-trailing-whitespace',
-			'',
 			'checkitem document-auto-indention',
+			'checkitem document-brace-indention',
 			'',
-			'item edit-document-convert-indent2spaces',
-			'item edit-document-convert-indent2tabs',
+			'checkitem view-editpanel-whitespace',
+			{'menu document_tab_width' => [
+				'checkitem document-tabs-width-1',
+				'checkitem document-tabs-width-2',
+				'checkitem document-tabs-width-3',
+				'checkitem document-tabs-width-4',
+				'checkitem document-tabs-width-5',
+				'checkitem document-tabs-width-6',
+				'checkitem document-tabs-width-8',
+			],},
+			{'menu document_convert' => [
+				'item edit-document-convert-tabs2spaces',
+				'item edit-document-convert-spaces2tabs',
+				'',
+				'item edit-document-convert-indent2spaces',
+				'item edit-document-convert-indent2tabs',
+				'',
+				'item edit-document-format-del-trailing-whitespace',
+			],},
 			'',
-			'item edit-document-convert-tabs2spaces',
-			'item edit-document-convert-spaces2tabs',
-			'',
-			'checkitem document-tabs-soft',
-			'checkitem document-tabs-hard',
+			'radioitem document-tabs-soft',
+			'radioitem document-tabs-hard',
 		],
 		'document_lineendchar_contextmenu' => [
 			'checkitem view-editpanel-EOL',
 			'',
 			'item document-EOL-auto',
 			'',
-			'checkitem document-EOL-lf',
-			'checkitem document-EOL-cr',
-			'checkitem document-EOL-cr+lf',
+			'radioitem document-EOL-lf',
+			'radioitem document-EOL-cr',
+			'radioitem document-EOL-cr+lf',
 		],
 		'document_info_contexmenu' => [
 			'radioitem view-statusbar-info-none',
