@@ -1,26 +1,9 @@
 package Kephra::Dialog::Search;
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 use strict;
 use warnings;
 
-use Wx qw(
-	wxVERTICAL wxHORIZONTAL wxLEFT wxRIGHT wxTOP wxBOTTOM wxGROW 
-	wxALIGN_LEFT wxALIGN_CENTER wxALIGN_RIGHT
-	wxALIGN_CENTER_VERTICAL wxALIGN_CENTER_HORIZONTAL 
-	wxSYSTEM_MENU wxCAPTION wxNO_FULL_REPAINT_ON_RESIZE wxCLOSE_BOX
-	wxMINIMIZE_BOX wxSTAY_ON_TOP wxSIMPLE_BORDER wxRAISED_BORDER
-	wxLI_HORIZONTAL
-	wxTE_PROCESS_ENTER
-	wxBITMAP_TYPE_XPM
-	WXK_BACK WXK_TAB WXK_ESCAPE WXK_RETURN WXK_SPACE
-);
-
-use Wx::Event qw(
-	EVT_KEY_DOWN EVT_TEXT EVT_BUTTON EVT_CHECKBOX EVT_RADIOBUTTON EVT_CLOSE 
-	EVT_CHAR EVT_TEXT_ENTER EVT_ENTER_WINDOW
-);
-
 sub _ID     { 'search_dialog' }
 sub _ref {
 	if (ref $_[0] eq 'Wx::Dialog'){ $Kephra::app{dialog}{search} = $_[0] }
@@ -67,9 +50,9 @@ sub ready {
 		my $hint            = $l18n->{dialog}{search}{hint};
 		my @find_history    = ();
 		my @replace_history = ();
-		my $d_style = wxNO_FULL_REPAINT_ON_RESIZE | wxSYSTEM_MENU | wxCAPTION
-			| wxMINIMIZE_BOX | wxCLOSE_BOX;
-		$d_style |= wxSTAY_ON_TOP if $Kephra::config{app}{window}{stay_on_top};
+		my $d_style = &Wx::wxNO_FULL_REPAINT_ON_RESIZE | &Wx::wxSYSTEM_MENU | 
+			&Wx::wxCAPTION | &Wx::wxMINIMIZE_BOX | &Wx::wxCLOSE_BOX;
+		$d_style |= &Wx::wxSTAY_ON_TOP if $Kephra::config{app}{window}{stay_on_top};
 		$dsettings->{position_x} = 10 if $dsettings->{position_x} < 0;
 		$dsettings->{position_y} = 10 if $dsettings->{position_y} < 0;
 		$dsettings->{width} = Wx::wxMSW() ? 436 : 466;
@@ -100,11 +83,16 @@ sub ready {
 		# input boxes with labels
 		$d->{find_label}   = Wx::StaticText->new($d, -1, $label->{search_for} );
 		$d->{replace_label}= Wx::StaticText->new($d, -1, $label->{replace_with} );
-		$d->{find_input} = Wx::ComboBox->new($d, -1,'', [-1,-1], [324,22], [@find_history], wxTE_PROCESS_ENTER );
-		$d->{find_input}->SetDropTarget( SearchInputTarget->new($d->{find_input}, 'find'));
-		$d->{replace_input} = Wx::ComboBox->new($d, -1, '', [-1,-1], [324,22], [@replace_history], wxTE_PROCESS_ENTER);
-		$d->{replace_input}->SetDropTarget( SearchInputTarget->new($d->{replace_input}, 'replace'));
-		$d->{sep_line} = Wx::StaticLine->new($d, -1, [0,0], [420,1], wxLI_HORIZONTAL,);
+		$d->{find_input} = Wx::ComboBox->new
+			($d, -1,'', [-1,-1], [324,22], [@find_history], &Wx::wxTE_PROCESS_ENTER );
+		$d->{find_input}->SetDropTarget
+			( SearchInputTarget->new($d->{find_input}, 'find'));
+		$d->{replace_input} = Wx::ComboBox->new
+			($d, -1, '', [-1,-1], [324,22], [@replace_history], &Wx::wxTE_PROCESS_ENTER);
+		$d->{replace_input}->SetDropTarget
+			( SearchInputTarget->new($d->{replace_input}, 'replace'));
+		$d->{sep_line} = Wx::StaticLine->new(
+			$d, -1, [0,0], [420,1], &Wx::wxLI_HORIZONTAL,);
 
 		# search attributes checkboxes
 		$d->{inc_box}  = Wx::CheckBox->new($d, -1, $label->{incremental});
@@ -122,7 +110,7 @@ sub ready {
 
 		# range radio group
 		my $range_box = Wx::StaticBox->new($d, -1, $label->{search_in},
-			[-1,-1], [-1,-1], wxSIMPLE_BORDER | wxRAISED_BORDER,
+			[-1,-1], [-1,-1], &Wx::wxSIMPLE_BORDER | &Wx::wxRAISED_BORDER,
 		);
 		$d->{selection_radio}= Wx::RadioButton->new($d, -1, $label->{selection});
 		$d->{document_radio} = Wx::RadioButton->new($d, -1, $label->{document} );
@@ -163,70 +151,70 @@ sub ready {
 		}
 
 		# eventhandling
-		EVT_KEY_DOWN($d->{find_input},       \&find_input_keyfilter );
-		EVT_KEY_DOWN($d->{replace_input},    \&replace_input_keyfilter );
-		EVT_TEXT($d, $d->{find_input},       \&incremental_search );
-		EVT_TEXT($d, $d->{replace_input}, sub {
+		Wx::Event::EVT_KEY_DOWN($d->{find_input},       \&find_input_keyfilter );
+		Wx::Event::EVT_KEY_DOWN($d->{replace_input},    \&replace_input_keyfilter );
+		Wx::Event::EVT_TEXT($d, $d->{find_input},       \&incremental_search );
+		Wx::Event::EVT_TEXT($d, $d->{replace_input}, sub {
 			my $input = $d->{replace_input};
 			my $pos   = $input->GetInsertionPoint;
 			Kephra::Edit::Search::set_replace_item( $input->GetValue );
 			$input->SetInsertionPoint($pos);
 		});
-		EVT_CHECKBOX($d, $d->{case_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{case_box}, sub {
 			$$attr{match_case} = $d->{case_box}->GetValue;
 			Kephra::Edit::Search::_refresh_search_flags();
 		} );
-		EVT_CHECKBOX($d, $d->{begin_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{begin_box}, sub {
 			$$attr{match_word_begin} = $d->{begin_box}->GetValue;
 			Kephra::Edit::Search::_refresh_search_flags();
 		} );
-		EVT_CHECKBOX($d, $d->{word_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{word_box}, sub {
 			$$attr{match_whole_word} = $d->{word_box}->GetValue;
 			Kephra::Edit::Search::_refresh_search_flags();
 		} );
-		EVT_CHECKBOX($d, $d->{regex_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{regex_box}, sub {
 			$$attr{match_regex} = $d->{regex_box}->GetValue;
 			Kephra::Edit::Search::_refresh_search_flags();
 		} );
-		EVT_CHECKBOX($d, $d->{wrap_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{wrap_box}, sub {
 			$$attr{auto_wrap} = $d->{wrap_box}->GetValue;
 		} );
-		EVT_CHECKBOX($d, $d->{inc_box}, sub {
+		Wx::Event::EVT_CHECKBOX($d, $d->{inc_box}, sub {
 			$$attr{incremental} = $d->{inc_box}->GetValue;
 		} );
-		EVT_RADIOBUTTON($d, $d->{selection_radio},sub {$attr->{in} = 'selection'});
-		EVT_RADIOBUTTON($d, $d->{document_radio}, sub {$attr->{in} = 'document'});
-		EVT_RADIOBUTTON($d, $d->{all_open_radio}, sub {$attr->{in} = 'open_docs'});
-		EVT_BUTTON($d, $d->{foreward_button}, sub {
+		Wx::Event::EVT_RADIOBUTTON($d, $d->{selection_radio},sub {$attr->{in} = 'selection'});
+		Wx::Event::EVT_RADIOBUTTON($d, $d->{document_radio}, sub {$attr->{in} = 'document'});
+		Wx::Event::EVT_RADIOBUTTON($d, $d->{all_open_radio}, sub {$attr->{in} = 'open_docs'});
+		Wx::Event::EVT_BUTTON($d, $d->{foreward_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::find_next();
 		} );
-		EVT_BUTTON($d, $d->{backward_button}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{backward_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::find_prev();
 		} );
-		EVT_BUTTON($d, $d->{fast_fore_button}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{fast_fore_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::fast_fore();
 		} );
-		EVT_BUTTON($d, $d->{fast_back_button}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{fast_back_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::fast_back();
 		} );
-		EVT_BUTTON($d, $d->{first_button}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{first_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::find_first();
 		} );
-		EVT_BUTTON($d, $d->{last_button}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{last_button}, sub {
 			&no_sel_range; Kephra::Edit::Search::find_last();
 		} );
-		EVT_BUTTON($d, $d->{replace_fore}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{replace_fore}, sub {
 			&no_sel_range; Kephra::Edit::Search::replace_fore();
 		} );
-		EVT_BUTTON($d, $d->{replace_back}, sub {
+		Wx::Event::EVT_BUTTON($d, $d->{replace_back}, sub {
 			&no_sel_range; Kephra::Edit::Search::replace_back();
 		} );
-		EVT_BUTTON($d, $d->{search_button},  sub{ &Kephra::Edit::Search::find_first } );
-		EVT_BUTTON($d, $d->{replace_button}, sub{ &Kephra::Edit::Search::replace_all } );
-		EVT_BUTTON($d, $d->{confirm_button}, sub{ &Kephra::Edit::Search::replace_confirm } );
-		EVT_BUTTON($d, $d->{close_button},   sub{ shift->Close() } );
+		Wx::Event::EVT_BUTTON($d, $d->{search_button},  sub{ &Kephra::Edit::Search::find_first } );
+		Wx::Event::EVT_BUTTON($d, $d->{replace_button}, sub{ &Kephra::Edit::Search::replace_all } );
+		Wx::Event::EVT_BUTTON($d, $d->{confirm_button}, sub{ &Kephra::Edit::Search::replace_confirm } );
+		Wx::Event::EVT_BUTTON($d, $d->{close_button},   sub{ shift->Close() } );
 
-		EVT_CLOSE( $d, \&quit_search_dialog );
+		Wx::Event::EVT_CLOSE( $d, \&quit_search_dialog );
 
 
 		my $ID = _ID();
@@ -277,20 +265,20 @@ sub ready {
 		}
 
 		# asembling
-		my $option_sizer = Wx::BoxSizer->new(wxVERTICAL);
-		$option_sizer->Add( $d->{inc_box},   0, wxTOP,  0 );
-		$option_sizer->Add( $d->{case_box},  0, wxTOP, 15 );
-		$option_sizer->Add( $d->{begin_box}, 0, wxTOP,  5 );
-		$option_sizer->Add( $d->{word_box},  0, wxTOP,  5 );
-		$option_sizer->Add( $d->{regex_box}, 0, wxTOP,  5 );
+		my $option_sizer = Wx::BoxSizer->new(&Wx::wxVERTICAL);
+		$option_sizer->Add( $d->{inc_box},   0, &Wx::wxTOP,  0 );
+		$option_sizer->Add( $d->{case_box},  0, &Wx::wxTOP, 15 );
+		$option_sizer->Add( $d->{begin_box}, 0, &Wx::wxTOP,  5 );
+		$option_sizer->Add( $d->{word_box},  0, &Wx::wxTOP,  5 );
+		$option_sizer->Add( $d->{regex_box}, 0, &Wx::wxTOP,  5 );
 
-		my $rbz = Wx::StaticBoxSizer->new( $range_box, wxVERTICAL );
-		$rbz->Add( $d->{selection_radio}, 1, wxTOP, 5 );
-		$rbz->Add( $d->{document_radio},  1, wxTOP, 5 );
-		$rbz->Add( $d->{all_open_radio},  1, wxTOP, 5 );
-		my $range_sizer = Wx::BoxSizer->new(wxVERTICAL);
-		$range_sizer->Add( $d->{wrap_box}, 0, wxTOP|wxALIGN_CENTER_HORIZONTAL, 0 );
-		$range_sizer->Add( $rbz, 0, wxGROW | wxTOP, 10 );
+		my $rbz = Wx::StaticBoxSizer->new( $range_box, &Wx::wxVERTICAL );
+		$rbz->Add( $d->{selection_radio}, 1, &Wx::wxTOP, 5 );
+		$rbz->Add( $d->{document_radio},  1, &Wx::wxTOP, 5 );
+		$rbz->Add( $d->{all_open_radio},  1, &Wx::wxTOP, 5 );
+		my $range_sizer = Wx::BoxSizer->new(&Wx::wxVERTICAL);
+		$range_sizer->Add( $d->{wrap_box}, 0, &Wx::wxTOP|&Wx::wxALIGN_CENTER_HORIZONTAL, 0 );
+		$range_sizer->Add( $rbz, 0, &Wx::wxGROW | &Wx::wxTOP, 10 );
 
 		my $pad_grid = Wx::FlexGridSizer->new( 4, 2, 0 , 1 );
 		$pad_grid->Add( $d->{replace_back}, 0, wxBOTTOM, 5);
@@ -302,30 +290,30 @@ sub ready {
 		$pad_grid->Add( $d->{first_button},    0, ,0);
 		$pad_grid->Add( $d->{last_button},     0, ,0);
 
-		my $pads_sizer = Wx::BoxSizer->new(wxHORIZONTAL);
-		$pads_sizer->Add( $option_sizer,0,wxALIGN_LEFT  ,0);
-		$pads_sizer->Add( $range_sizer ,1,wxALIGN_CENTER|wxLEFT|wxRIGHT|wxGROW ,20);
-		$pads_sizer->Add( $pad_grid    ,0,wxALIGN_RIGHT ,0);
+		my $pads_sizer = Wx::BoxSizer->new(&Wx::wxHORIZONTAL);
+		$pads_sizer->Add( $option_sizer,0,&Wx::wxALIGN_LEFT  ,0);
+		$pads_sizer->Add( $range_sizer ,1,&Wx::wxALIGN_CENTER|&Wx::wxLEFT|&Wx::wxRIGHT|&Wx::wxGROW ,20);
+		$pads_sizer->Add( $pad_grid    ,0,&Wx::wxALIGN_RIGHT ,0);
 
-		my $button_sizer = Wx::BoxSizer->new(wxHORIZONTAL);
-		$button_sizer->Add( $d->{search_button},  0, wxLEFT, 15 );
-		$button_sizer->Add( $d->{replace_button}, 0, wxLEFT, 10 );
-		$button_sizer->Add( $d->{confirm_button}, 0, wxLEFT, 10 );
+		my $button_sizer = Wx::BoxSizer->new(&Wx::wxHORIZONTAL);
+		$button_sizer->Add( $d->{search_button},  0, &Wx::wxLEFT, 15 );
+		$button_sizer->Add( $d->{replace_button}, 0, &Wx::wxLEFT, 10 );
+		$button_sizer->Add( $d->{confirm_button}, 0, &Wx::wxLEFT, 10 );
 		$button_sizer->AddStretchSpacer;
-		$button_sizer->Add( $d->{close_button},   0, wxALIGN_RIGHT|wxRIGHT, 15 );
+		$button_sizer->Add( $d->{close_button},   0, &Wx::wxALIGN_RIGHT|&Wx::wxRIGHT, 15 );
 
 		my $b_grid = Wx::FlexGridSizer->new( 3, 2, 10, 0 );
-		$b_grid->Add($d->{find_label}, 0, wxLEFT | wxRIGHT | wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 10);
-		$b_grid->Add($d->{find_input}, 0, wxTOP, 0);
-		$b_grid->Add($d->{replace_label}, 0, wxLEFT | wxRIGHT | wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT, 10);
-		$b_grid->Add($d->{replace_input}, 0, wxTOP, 0);
+		$b_grid->Add($d->{find_label}, 0, &Wx::wxLEFT | &Wx::wxRIGHT | &Wx::wxALIGN_CENTER_VERTICAL | &Wx::wxALIGN_RIGHT, 10);
+		$b_grid->Add($d->{find_input}, 0, &Wx::wxTOP, 0);
+		$b_grid->Add($d->{replace_label}, 0, &Wx::wxLEFT | &Wx::wxRIGHT | &Wx::wxALIGN_CENTER_VERTICAL | &Wx::wxALIGN_RIGHT, 10);
+		$b_grid->Add($d->{replace_input}, 0, &Wx::wxTOP, 0);
 		$b_grid->AddSpacer(5);
-		$b_grid->Add($pads_sizer, 1, wxTOP|wxGROW, 5);
+		$b_grid->Add($pads_sizer, 1, &Wx::wxTOP|&Wx::wxGROW, 5);
 
-		my $d_sizer = Wx::BoxSizer->new(wxVERTICAL);
-		$d_sizer->Add($b_grid,          1, wxTOP                            , 15);
-		$d_sizer->Add($d->{sep_line},   0, wxTOP | wxALIGN_CENTER_HORIZONTAL | wxGROW,  8);
-		$d_sizer->Add($button_sizer,    0, wxTOP | wxBOTTOM | wxGROW        ,  9);
+		my $d_sizer = Wx::BoxSizer->new(&Wx::wxVERTICAL);
+		$d_sizer->Add($b_grid,          1, &Wx::wxTOP                            , 15);
+		$d_sizer->Add($d->{sep_line},   0, &Wx::wxTOP | &Wx::wxALIGN_CENTER_HORIZONTAL | &Wx::wxGROW,  8);
+		$d_sizer->Add($button_sizer,    0, &Wx::wxTOP | &Wx::wxBOTTOM | &Wx::wxGROW        ,  9);
 
 		$d->SetSizer($d_sizer);
 		$d->SetAutoLayout(1);
@@ -366,15 +354,15 @@ sub find_input_keyfilter {
 	my $dialog = $Kephra::app{dialog}{search};
 	my $wx_frame = $dialog->GetParent;
 	my $key_code = $event->GetKeyCode;
-	if ($key_code == WXK_RETURN) {
+	if ($key_code == &Wx::WXK_RETURN) {
 		no_sel_range();
 		if    ($event->ControlDown){Kephra::Edit::Search::find_first(); $dialog->Close; } 
 		elsif ($event->ShiftDown  ){Kephra::Edit::Search::find_prev() }
 		else                       {Kephra::Edit::Search::find_next() }
 		return;
 	}
-	elsif ($key_code == WXK_ESCAPE) { $dialog->Close }
-	elsif ($key_code == WXK_TAB){
+	elsif ($key_code == &Wx::WXK_ESCAPE) { $dialog->Close }
+	elsif ($key_code == &Wx::WXK_TAB){
 		if ( $event->ShiftDown ) { $dialog->{close_button}->SetFocus } 
 		else                     { $dialog->{replace_input}->SetFocus}
 	}
@@ -420,15 +408,15 @@ sub replace_input_keyfilter {
 	my ($input, $event) = @_;
 	my $dialog = $Kephra::app{dialog}{search};
 	my $key_code = $event->GetKeyCode;
-	if ($key_code == WXK_RETURN ) {
+	if ($key_code == &Wx::WXK_RETURN ) {
 		if ( $event->ControlDown ) {
 			Kephra::Edit::Search::replace_all();
 			$dialog->Close;
 		} elsif ( $event->AltDown ) { replace_confirm($dialog) }
 		else                        { Kephra::Edit::Search::replace_all() }
 	}
-	if ( $key_code == WXK_ESCAPE) { $dialog->Close }
-	elsif ($key_code == WXK_TAB){
+	if ( $key_code == &Wx::WXK_ESCAPE) { $dialog->Close }
+	elsif ($key_code == &Wx::WXK_TAB){
 		if ( $event->ShiftDown ) { $dialog->{find_input}->SetFocus } 
 		else                     { $dialog->{inc_box}->SetFocus }
 	}
